@@ -252,7 +252,7 @@ Type *SPIRVTypeScavenger::substituteTypeVariables(Type *T) {
   }
   if (auto Index = isTypeVariable(T)) {
     unsigned TypeVarNum = *Index;
-    TypeVarNum = UnifiedTypeVars.join(TypeVarNum, TypeVarNum);
+    TypeVarNum = UnifiedTypeVars.findLeader(TypeVarNum);
     Type *&SubstTy = TypeVariables[TypeVarNum];
     // A value in TypeVariables may itself contain type variables that need to
     // be substituted. Substitute these as well.
@@ -273,9 +273,7 @@ bool SPIRVTypeScavenger::unifyType(Type *T1, Type *T2) {
     return true;
 
   auto SetTypeVar = [&](unsigned TypeVarNum, Type *ActualTy) {
-    // .findLeader doesn't work in uncompressed mode, so use .join with itself
-    // to find the leader.
-    unsigned Leader = UnifiedTypeVars.join(TypeVarNum, TypeVarNum);
+    unsigned Leader = UnifiedTypeVars.findLeader(TypeVarNum);
 
     // This method might be called with T1 as a concrete type containing
     // pointers, and we want to make sure those don't leak into type variables.
@@ -411,7 +409,7 @@ void SPIRVTypeScavenger::typeModule(Module &M) {
   // them as an i8* type.
   Type *Int8Ty = Type::getInt8Ty(M.getContext());
   for (const auto &[TypeVarNum, TypeVar] : enumerate(TypeVariables)) {
-    unsigned PrimaryVar = UnifiedTypeVars.join(TypeVarNum, TypeVarNum);
+    unsigned PrimaryVar = UnifiedTypeVars.findLeader(TypeVarNum);
     Type *LeaderTy = TypeVariables[PrimaryVar];
     if (TypeVar)
       TypeVar = substituteTypeVariables(TypeVar);
@@ -455,7 +453,6 @@ bool SPIRVTypeScavenger::typeIntrinsicCall(
     case OpAtomicLoad:
     case OpAtomicExchange:
     case OpAtomicCompareExchange:
-    case OpAtomicCompareExchangeWeak:
     case OpAtomicIAdd:
     case OpAtomicISub:
     case OpAtomicFAddEXT:
@@ -560,7 +557,7 @@ bool SPIRVTypeScavenger::typeIntrinsicCall(
     default:
       return false;
     }
-  } else if (TargetFn->getName().startswith("_Z18__spirv_ocl_printf")) {
+  } else if (TargetFn->getName().starts_with("_Z18__spirv_ocl_printf")) {
     Type *Int8Ty = Type::getInt8Ty(Ctx);
     // The first argument is a string pointer. Subsequent arguments may include
     // pointer-valued arguments, corresponding to %s or %p parameters.
@@ -620,12 +617,6 @@ void SPIRVTypeScavenger::typeGlobalValue(GlobalValue &GV, Constant *Init) {
       auto It = DeducedTypes.find(C);
       if (It != DeducedTypes.end())
         return It->second;
-    } else if (auto *GEP = dyn_cast<GEPOperator>(C)) {
-      auto *ResultTy =
-          TypedPointerType::get(GEP->getResultElementType(),
-                                GEP->getType()->getPointerAddressSpace());
-      DeducedTypes[C] = ResultTy;
-      return ResultTy;
     }
 
     return getUnknownTyped(C->getType());
@@ -736,8 +727,8 @@ void SPIRVTypeScavenger::deduceFunctionType(Function &F) {
   // existing code can propagate types to the parameters.
   // TODO: Investigate if target extension types and the specially-handled
   // SPIR-V intrinsics renders this code unnecessary.
-  if (F.isDeclaration() && F.getName().startswith("_Z")) {
-    if (F.getName().startswith("_Z")) {
+  if (F.isDeclaration() && F.getName().starts_with("_Z")) {
+    if (F.getName().starts_with("_Z")) {
       SmallVector<Type *, 8> ParamTypes;
       if (getParameterTypes(&F, ParamTypes)) {
         for (Argument *Arg : PointerArgs) {
